@@ -16,7 +16,6 @@
 import os
 import sys
 
-import openstackdocstheme
 
 sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__),
                 '..', '..')))
@@ -39,9 +38,9 @@ apidoc_excluded_paths = [
 apidoc_separate_modules = True
 
 # openstackdocstheme options
-repository_name = 'openstack/python-glanceclient'
-bug_project = 'python-glanceclient'
-bug_tag = ''
+openstackdocs_repo_name = 'openstack/python-glanceclient'
+openstackdocs_bug_project = 'python-glanceclient'
+openstackdocs_bug_tag = ''
 
 # autodoc generation is a bit aggressive and a nuisance when doing heavy
 # text edit cycles.
@@ -58,7 +57,7 @@ master_doc = 'index'
 
 # General information about the project.
 project = 'python-glanceclient'
-copyright = u'OpenStack Foundation'
+copyright = 'OpenStack Foundation'
 
 # If true, '()' will be appended to :func: etc. cross-reference text.
 add_function_parentheses = True
@@ -68,7 +67,7 @@ add_function_parentheses = True
 add_module_names = True
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
+pygments_style = 'native'
 
 # -- Options for HTML output --------------------------------------------------
 
@@ -77,10 +76,6 @@ pygments_style = 'sphinx'
 #html_theme = 'nature'
 html_theme = 'openstackdocs'
 
-# Add any paths that contain custom themes here, relative to this directory.
-#html_theme_path = ['_theme']
-html_theme_path = [openstackdocstheme.get_html_theme_path()]
-
 # Output file base name for HTML help builder.
 htmlhelp_basename = '%sdoc' % project
 
@@ -88,8 +83,8 @@ htmlhelp_basename = '%sdoc' % project
 # -- Options for man page output ----------------------------------------------
 
 # Grouping the document tree for man pages.
-# List of tuples 'sourcefile', 'target', u'title', u'Authors name', 'manual'
+# List of tuples 'sourcefile', 'target', 'title', 'Authors name', 'manual'
 man_pages = [
-    ('cli/glance', 'glance', u'Client for OpenStack Images API',
-     [u'OpenStack Foundation'], 1),
+    ('cli/glance', 'glance', 'Client for OpenStack Images API',
+     ['OpenStack Foundation'], 1),
 ]
